# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.roll_shap <- function(x, y, width, weights, intercept, min_obs, complete_obs, na_restore, online) {
    .Call(`_rollshap_roll_shap`, x, y, width, weights, intercept, min_obs, complete_obs, na_restore, online)
}

